summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xbin/test_torbrowser-launcher.sh5
1 files changed, 4 insertions, 1 deletions
diff --git a/bin/test_torbrowser-launcher.sh b/bin/test_torbrowser-launcher.sh
index c9eebc20..455bf435 100755
--- a/bin/test_torbrowser-launcher.sh
+++ b/bin/test_torbrowser-launcher.sh
@@ -150,8 +150,10 @@ announce_problem_and_abort_silently() {
prepare_other_packages() {
if $VIA_TOR ; then
+ echo "$(date -u ) - installing tor as this test will download torbrowser via the system tor service."
schroot --run-session -c $SESSION --directory $TMPDIR -u root -- apt-get install -y tor
else
+ echo "$(date -u ) - installing ca-certificates as this test will download torbrowser via https."
schroot --run-session -c $SESSION --directory $TMPDIR -u root -- apt-get install -y ca-certificates
fi
}
@@ -247,10 +249,11 @@ download_and_launch() {
sleep 20
update_screenshot
if $VIA_TOR ; then
# download via tor
echo "$(date -u) - pressing <space>"
xvkbd -text "\[space]" > /dev/null 2>&1
fi
+ # else the default will be used, which is download via https…
echo "$(date -u) - pressing <tab>"
xvkbd -text "\t" > /dev/null 2>&1
sleep 1
@@ -247,10 +249,11 @@ download_and_launch() {
update_screenshot
if $VIA_TOR ; then
- # download via tor
+ # download via system tor
echo "$(date -u) - pressing <space>"
xvkbd -text "\[space]" > /dev/null 2>&1